==> inspirational-quotes-1.0.3.tgz: package/README.md <==
# Inspirational Quotes

> A simple node module which returns **Inspirational Quotes**. It provides awesome quotes to display in your application. Get your daily quote and stay motivated!

[![NPM VERSION](http://img.shields.io/npm/v/inspirational-quotes.svg?style=flat)](https://www.npmjs.org/package/inspirational-quotes) [![GitHub license](https://img.shields.io/github/license/vinitshahdeo/inspirational-quotes.svg?style=flat)](https://github.com/vinitshahdeo/inspirational-quotes/blob/master/LICENSE) [![LICENSE](http://img.shields.io/badge/inspirational-quotes-orange.svg?style=flat)](https://github.com/vinitshahdeo/inspirational-quotes)

## Getting started

```
$ npm install --save inspirational-quotes
```

## Installation

[![NPM INSTALL](http://img.shields.io/badge/npm-install-blue.svg?style=flat)](https://docs.npmjs.com/getting-started/installing-npm-packages-locally) [![NODE JS](http://img.shields.io/badge/Node-JS-teal.svg?style=flat)](https://nodejs.org/en/) 


This is a [Node.js](https://nodejs.org/en/) module available through the
[npm registry](https://www.npmjs.com/).

Before installing, [download and install Node.js](https://nodejs.org/en/download/).

Installation is done using the
**[`npm install`](https://docs.npmjs.com/getting-started/installing-npm-packages-locally)** command:

```bash
$ npm install inspirational-quotes
```

## Usage

- ***getQuote()*** method returns an object containing ***text*** and ***author***.

```json
 {  
    "text":"My number one piece of advice is: you should learn how to program.",
    "from":"Mark Zuckerberg, founder of Facebook"
 }
 ```
 
 

- ***getRandomQuote()*** method returns a random **inspirational** quote : *`You miss 100 percent of the shots you don’t take.`*



```js

const Quote = require('inspirational-quotes');

console.log(Quote.getRandomQuote());

console.log(Quote.getQuote());

```

## Examples

To view the examples, clone the **inspirational-quotes** repo and install the dependencies:

```bash
$ git clone https://github.com/vinitshahdeo/inspirational-quotes.git
$ cd examples
$ npm install
```

Then run the **demo.js**:

```bash
$ node demo.js
```

## License


[![GitHub license](https://img.shields.io/github/license/vinitshahdeo/inspirational-quotes.svg?style=social)](https://github.com/vinitshahdeo/inspirational-quotes/blob/master/LICENSE)

**MIT &copy; [Vinit Shahdeo](https://github.com/vinitshahdeo/inspirational-quotes/blob/master/LICENSE)**

## Oh, Thanks!

Thank you for being here! You can find other NPM Packages **[here](https://www.npmjs.com/~vinitshahdeo)**.


Let's **`get connected`** if we share the same views! 
Invite me to connect on **[LinkedIn](https://www.linkedin.com/in/vinitshahdeo/)**.
 
[![Twitter](https://img.shields.io/twitter/url/https/github.com/vinitshahdeo/TwitterSentimentAnalysis.svg?style=social)](https://twitter.com/intent/tweet?text=A%20NPM%20module%20by%20@Vinit_Shahdeo%20to%20keep%20yourself%20motivated:&url=https://github.com/vinitshahdeo/inspirational-quotes/)

> **One day your life will flash before your eyes. Make sure it is worth watching!**

[![Stay Motivated](https://img.shields.io/badge/Stay-Motivated-teal.svg?style=for-the-badge)](https://github.com/vinitshahdeo/inspirational-quotes) 
[![Think Big](https://img.shields.io/badge/Think-Big-orange.svg?style=for-the-badge)](https://github.com/vinitshahdeo/GetQuotes)
[![Work Hard](https://img.shields.io/badge/Work-Hard-blue.svg?style=for-the-badge)](https://github.com/vinitshahdeo/)

==> inspirational-quotes-1.0.4.tgz: package/README.md <==
# Inspirational Quotes

> A simple node module which returns **Inspirational Quotes**. It provides awesome quotes to display in your application. Get your daily quote and stay motivated!

[![NPM VERSION](http://img.shields.io/npm/v/inspirational-quotes.svg?style=flat)](https://www.npmjs.org/package/inspirational-quotes) [![GitHub license](https://img.shields.io/github/license/vinitshahdeo/inspirational-quotes.svg?style=flat)](https://github.com/vinitshahdeo/inspirational-quotes/blob/master/LICENSE) [![LICENSE](http://img.shields.io/badge/inspirational-quotes-orange.svg?style=flat)](https://github.com/vinitshahdeo/inspirational-quotes)

## Getting started

```
$ npm install --save inspirational-quotes
```

## Installation

[![NPM INSTALL](http://img.shields.io/badge/npm-install-blue.svg?style=flat)](https://docs.npmjs.com/getting-started/installing-npm-packages-locally) [![NODE JS](http://img.shields.io/badge/Node-JS-teal.svg?style=flat)](https://nodejs.org/en/) 


This is a [Node.js](https://nodejs.org/en/) module available through the
[npm registry](https://www.npmjs.com/).

Before installing, [download and install Node.js](https://nodejs.org/en/download/).

Installation is done using the
**[`npm install`](https://docs.npmjs.com/getting-started/installing-npm-packages-locally)** command:

```bash
$ npm install inspirational-quotes
```

## Usage

- ***getQuote()*** method returns an object containing ***text*** and ***author***.

```json
 {  
    "text":"My number one piece of advice is: you should learn how to program.",
    "author":"Mark Zuckerberg, founder of Facebook"
 }
 ```
 
 

- ***getRandomQuote()*** method returns a random **inspirational** quote : *`You miss 100 percent of the shots you don’t take.`*



```js

const Quote = require('inspirational-quotes');

console.log(Quote.getRandomQuote());

console.log(Quote.getQuote());

```

## Examples

To view the examples, clone the **inspirational-quotes** repo and install the dependencies:

```bash
$ git clone https://github.com/vinitshahdeo/inspirational-quotes.git
$ cd examples
$ npm install
```

Then run the **demo.js**:

```bash
$ node demo.js
```

## License


[![GitHub license](https://img.shields.io/github/license/vinitshahdeo/inspirational-quotes.svg?style=social)](https://github.com/vinitshahdeo/inspirational-quotes/blob/master/LICENSE)

**MIT &copy; [Vinit Shahdeo](https://github.com/vinitshahdeo/inspirational-quotes/blob/master/LICENSE)**

## Oh, Thanks!

Thank you for being here! You can find other NPM Packages **[here](https://www.npmjs.com/~vinitshahdeo)**.


Let's **`get connected`** if we share the same views! 
Invite me to connect on **[LinkedIn](https://www.linkedin.com/in/vinitshahdeo/)**.
 
[![Twitter](https://img.shields.io/twitter/url/https/github.com/vinitshahdeo/TwitterSentimentAnalysis.svg?style=social)](https://twitter.com/intent/tweet?text=A%20NPM%20module%20by%20@Vinit_Shahdeo%20to%20keep%20yourself%20motivated:&url=https://github.com/vinitshahdeo/inspirational-quotes/)

> **One day your life will flash before your eyes. Make sure it is worth watching!**

[![Stay Motivated](https://img.shields.io/badge/Stay-Motivated-teal.svg?style=for-the-badge)](https://github.com/vinitshahdeo/inspirational-quotes) 
[![Think Big](https://img.shields.io/badge/Think-Big-orange.svg?style=for-the-badge)](https://github.com/vinitshahdeo/GetQuotes)
[![Work Hard](https://img.shields.io/badge/Work-Hard-blue.svg?style=for-the-badge)](https://github.com/vinitshahdeo/)
